@@ -45,16 +45,19 @@ my_draw (GnomePrintContext *gpc)
 static void
 my_print (void)
 {
-	GnomePrintJob *gpm;
 	GnomePrintContext *gpc;
+	GnomePrintJob *job;
 
-	gpm = gnome_print_job_new (NULL);
-	gpc = gnome_print_job_get_context (gpm);
+	job = gnome_print_job_new (NULL);
+	gpc = gnome_print_job_get_context (job);
 
 	my_draw (gpc);
 
-	gnome_print_job_close (gpm);
-	gnome_print_job_print (gpm);
+	gnome_print_job_close (job);
+	gnome_print_job_print (job);
+
+	g_object_unref (G_OBJECT (gpc));
+	g_object_unref (G_OBJECT (job));
 }
 
 int
