@@ -276,7 +276,7 @@ gnome_print_copies_selector_get_type (void)
 			sizeof (GnomePrintCopiesSelector),
 			0,
 			(GInstanceInitFunc) gnome_print_copies_selector_init,
-			NULL,
+			NULL
 		};
 		type = g_type_register_static (GTK_TYPE_VBOX, "GnomePrintCopiesSelector", &info, 0);
 	}
