@@ -533,7 +533,7 @@ gpa_printer_selector_printer_added (GPANode *parent, GPANode *child,
 					   GPA_PRINTER (child));
 
   	if (!ps->user_selected && ps->config != NULL)
-  		default_printer = GPA_REFERENCE_REFERENCE (GPA_CONFIG (ps->config)->printer);
+  		default_printer = gpa_printer_get_default ();
   
   	if (default_printer != NULL &&
   	    node_to_iter (ps->model, default_printer, &iter)) {
